
/*
 *
 * FILE: math.c
 * 
 * DESCRIPTION:
 * The functions to perform mathematical operations on 
 * observed quantities.
 *
 */

#include <stdio.h>
#include <math.h>
#include <stdlib.h>
#include "obsmath.h"


extern int verbose;


	/*************************************************************
	 * PROCEDURE: recenter_ellipse
	 * 
	 * DESCRIPTION: Translate all observations by the same fixed
	 *              amount in all 3 dimensions (x, y, z)
	 *              so that the mean value in each dimension is zero.
	 * 
	 * RETURNS:
	 *              0     if all goes well
	 *              1     if an error occurs
    */

int
recenter_ellipse
	(
	OBS *obs_list
	)
{
	int i, num;
	double sumx, sumy, sumz;
	double meanx, meany, meanz;
	OBS *this_obs;
	
	num = 0;
	sumx = 0.0;
	sumy = 0.0;
	sumz = 0.0;
	this_obs = obs_list;
	while (this_obs != NULL) {
		sumx += this_obs->x;
		sumy += this_obs->y;
		sumz += this_obs->z;
		num++;
		this_obs = this_obs->next;
	}

	meanx = sumx / (double) num;
	meany = sumy / (double) num;
	meanz = sumz / (double) num;

	if (verbose > 0) {
		printf("recenter_ellipse: num %6d  means %10.4e %10.4e %10.4e \n",
				num, meanx, meany, meanz);
	}

	/* now we modify the positions of each measurement */
	this_obs = obs_list;
	while (this_obs != NULL) {
		this_obs->x -= meanx;
		this_obs->y -= meany;
		this_obs->z -= meanz;
		this_obs = this_obs->next;
	}
	
	return(0);
}






